﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Text.RegularExpressions;
using System.IO;
using CTNet;

namespace ChkBoxCtrl
{
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>

        /*
         * Application was launched from a code editor:
         * Verify launch arguments returning true or false.
         * 
         * Called From: Main(string[] args).
         */
        public static bool ProcessArgs(string[] args)
        {
            bool ret = false;

            Form1.editorLaunch = true;

            /*
             * Caller has ensured args.Length > 0.
             */
            if (args.Length == 1)
            {
                Form1.vscFileInfo = new VSCFileInfo();
                Form1.vscFileInfo.VerifyFileInfo(args[0]);

                switch (Form1.vscFileInfo.verifyResult)
                {
                    // Probably unlikely...
                    case (verifyFile.nullEmptyPath):
                        MessageBox.Show("  ChkBoxCtrl launched with arg[0] either null or empty:\n\n  Launch will be aborted.", "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    // Probably unlikely...
                    case (verifyFile.nullEmptyFileName):
                        MessageBox.Show("  ChkBoxCtrl launched with a null or empty file name.\n\n  Launch will be aborted.", "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    // Probably unlikely...
                    case (verifyFile.nullWorkFolder):
                        MessageBox.Show("  ChkBoxCtrl launched with a null folder.\n\n  Launch will be aborted.", "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case (verifyFile.notDocFile):
                        MessageBox.Show(string.Format("  ChkBoxCtrl launched from an editor file not belonging to a\n  document:\n\n  {0}\n\n  Launch will be aborted.", Form1.vscFileInfo.workFolderTmp), "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case (verifyFile.noZipFile):

                        /*
                         * Don't worry, we ended up asking the user where the
                         * zip file is located in the Form1_Shown() method. Doing it
                         * there somehow 'allows' the form to appear on the screen.
                         * If we do the dialog box asking for the location of the
                         * zip file here all you see is the form icon down on the
                         * taskbar and the only way to see the form is to click on
                         * the icon.
                         */
                        ret = true;

                        break;

                    case (verifyFile.exception):
                        MessageBox.Show("  An exception has occurred during file verification.\n\n  Launch will be aborted.", "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case (verifyFile.fileOk):
                        ret = true;
                        break;

                    default:
                        MessageBox.Show("  An exception has occurred during file verification.\n\n  Launch will be aborted.", "Check Box Control: Launch Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
            else
            {
                MessageBox.Show(string.Format("  Application launched with incorrect number of arguments.\n\n  Expecting 1 but received {0}.\n\n  Aborting Launch.", args.Length), "Check Box Control: Argument Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            return ret;
        }
       
        [STAThread]

        static void Main(string[] args)
        {
            //MessageBox.Show(string.Format("args length: {0}", args.Length));

            bool runForm = true;

            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

            // Launched from a code editor?
            if (args.Length > 0)
            {
                // We return true if the args check out ok.
                runForm = ProcessArgs(args);
            }

            try
            {
                if (runForm)
                {
                    Application.Run(new Form1(args));
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
